@@ -12,12 +12,12 @@ import re
 from flatten_any_dict_iterable_or_whatsoever import fla_tu, set_in_original_iter
 from flatten_everything import flatten_everything
 from tolerant_isinstance import isinstance_tolerant
-
 nested_dict = lambda: defaultdict(nested_dict)
 allvars = sys.modules[__name__]
 reg = re.compile(r"^[-.,\de+]+", flags=re.I)
 
 regint = re.compile(r"^[-\d+]+", flags=re.I)
+from deepcopyall import deepcopy
 
 
 def load_config_file_vars(cfgfile, onezeroasboolean):
@@ -645,7 +645,9 @@ class Cfedit:
         )
 
         if self.addbuttons:
+            buttonposition = True
             for bu in self.addbuttons:
+                buttonposition = not buttonposition
                 maxindex += 1
                 varabx = f"bu{maxindex}"
                 setattr(
@@ -654,14 +656,18 @@ class Cfedit:
                     tk.Button(
                         self.subframe_in_canvas,
                         text=str(bu[0]).center(self.maxlenabsvals),
-                        command=lambda: bu[1](),
+                        command=deepcopy(lambda: bu[1]()),
                         anchor="w", width=self._get_button_len(), font=self.buttonfont,
                         justify=tk.RIGHT,
                     ),
                 )
                 getattr(getattr(self, varabx), "grid")(
-                    row=maxindex, column=0, padx=1, pady=3
+                    row=maxindex, column=int(buttonposition), padx=1, pady=3
                 )
+                if buttonposition:
+                    maxindex += 1
+                else:
+                    maxindex-=1
 
         self.canvas_in_mainframe.bind("<Enter>", self._bound_to_mousewheel)
         self.canvas_in_mainframe.bind("<Leave>", self._unbound_to_mousewheel)
